/* This file is generated by glib-genmarshal, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */
#pragma once

#include <glib-object.h>

G_BEGIN_DECLS

/* BOOLEAN:BOOLEAN (../gtk/gtk/gtkmarshalers.list:24) */
extern
void _gtk_marshal_BOOLEAN__BOOLEAN (GClosure     *closure,
                                    GValue       *return_value,
                                    guint         n_param_values,
                                    const GValue *param_values,
                                    gpointer      invocation_hint,
                                    gpointer      marshal_data);
extern
void _gtk_marshal_BOOLEAN__BOOLEANv (GClosure *closure,
                                     GValue   *return_value,
                                     gpointer  instance,
                                     va_list   args,
                                     gpointer  marshal_data,
                                     int       n_params,
                                     GType    *param_types);

/* BOOLEAN:BOOLEAN,BOOLEAN,BOOLEAN (../gtk/gtk/gtkmarshalers.list:25) */
extern
void _gtk_marshal_BOOLEAN__BOOLEAN_BOOLEAN_BOOLEAN (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
                                                    const GValue *param_values,
                                                    gpointer      invocation_hint,
                                                    gpointer      marshal_data);
extern
void _gtk_marshal_BOOLEAN__BOOLEAN_BOOLEAN_BOOLEANv (GClosure *closure,
                                                     GValue   *return_value,
                                                     gpointer  instance,
                                                     va_list   args,
                                                     gpointer  marshal_data,
                                                     int       n_params,
                                                     GType    *param_types);

/* BOOLEAN:BOXED,BOXED (../gtk/gtk/gtkmarshalers.list:26) */
#define _gtk_marshal_BOOLEAN__BOXED_BOXED	g_cclosure_marshal_BOOLEAN__BOXED_BOXED
#define _gtk_marshal_BOOLEAN__BOXED_BOXEDv	g_cclosure_marshal_BOOLEAN__BOXED_BOXEDv

/* BOOLEAN:BOXED,DOUBLE,DOUBLE (../gtk/gtk/gtkmarshalers.list:27) */
extern
void _gtk_marshal_BOOLEAN__BOXED_DOUBLE_DOUBLE (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
                                                const GValue *param_values,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);
extern
void _gtk_marshal_BOOLEAN__BOXED_DOUBLE_DOUBLEv (GClosure *closure,
                                                 GValue   *return_value,
                                                 gpointer  instance,
                                                 va_list   args,
                                                 gpointer  marshal_data,
                                                 int       n_params,
                                                 GType    *param_types);

/* BOOLEAN:DOUBLE,DOUBLE (../gtk/gtk/gtkmarshalers.list:28) */
extern
void _gtk_marshal_BOOLEAN__DOUBLE_DOUBLE (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
                                          const GValue *param_values,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);
extern
void _gtk_marshal_BOOLEAN__DOUBLE_DOUBLEv (GClosure *closure,
                                           GValue   *return_value,
                                           gpointer  instance,
                                           va_list   args,
                                           gpointer  marshal_data,
                                           int       n_params,
                                           GType    *param_types);

/* BOOLEAN:ENUM (../gtk/gtk/gtkmarshalers.list:29) */
extern
void _gtk_marshal_BOOLEAN__ENUM (GClosure     *closure,
                                 GValue       *return_value,
                                 guint         n_param_values,
                                 const GValue *param_values,
                                 gpointer      invocation_hint,
                                 gpointer      marshal_data);
extern
void _gtk_marshal_BOOLEAN__ENUMv (GClosure *closure,
                                  GValue   *return_value,
                                  gpointer  instance,
                                  va_list   args,
                                  gpointer  marshal_data,
                                  int       n_params,
                                  GType    *param_types);

/* BOOLEAN:ENUM,BOOLEAN (../gtk/gtk/gtkmarshalers.list:30) */
extern
void _gtk_marshal_BOOLEAN__ENUM_BOOLEAN (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
                                         const GValue *param_values,
                                         gpointer      invocation_hint,
                                         gpointer      marshal_data);
extern
void _gtk_marshal_BOOLEAN__ENUM_BOOLEANv (GClosure *closure,
                                          GValue   *return_value,
                                          gpointer  instance,
                                          va_list   args,
                                          gpointer  marshal_data,
                                          int       n_params,
                                          GType    *param_types);

/* BOOLEAN:ENUM,BOXED,BOXED,BOXED (../gtk/gtk/gtkmarshalers.list:31) */
extern
void _gtk_marshal_BOOLEAN__ENUM_BOXED_BOXED_BOXED (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
                                                   const GValue *param_values,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);
extern
void _gtk_marshal_BOOLEAN__ENUM_BOXED_BOXED_BOXEDv (GClosure *closure,
                                                    GValue   *return_value,
                                                    gpointer  instance,
                                                    va_list   args,
                                                    gpointer  marshal_data,
                                                    int       n_params,
                                                    GType    *param_types);

/* BOOLEAN:ENUM,DOUBLE (../gtk/gtk/gtkmarshalers.list:32) */
extern
void _gtk_marshal_BOOLEAN__ENUM_DOUBLE (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
                                        const GValue *param_values,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);
extern
void _gtk_marshal_BOOLEAN__ENUM_DOUBLEv (GClosure *closure,
                                         GValue   *return_value,
                                         gpointer  instance,
                                         va_list   args,
                                         gpointer  marshal_data,
                                         int       n_params,
                                         GType    *param_types);

/* BOOLEAN:ENUM,INT,BOOLEAN,BOOLEAN (../gtk/gtk/gtkmarshalers.list:33) */
extern
void _gtk_marshal_BOOLEAN__ENUM_INT_BOOLEAN_BOOLEAN (GClosure     *closure,
                                                     GValue       *return_value,
                                                     guint         n_param_values,
                                                     const GValue *param_values,
                                                     gpointer      invocation_hint,
                                                     gpointer      marshal_data);
extern
void _gtk_marshal_BOOLEAN__ENUM_INT_BOOLEAN_BOOLEANv (GClosure *closure,
                                                      GValue   *return_value,
                                                      gpointer  instance,
                                                      va_list   args,
                                                      gpointer  marshal_data,
                                                      int       n_params,
                                                      GType    *param_types);

/* BOOLEAN:FLAGS (../gtk/gtk/gtkmarshalers.list:34) */
#define _gtk_marshal_BOOLEAN__FLAGS	g_cclosure_marshal_BOOLEAN__FLAGS
#define _gtk_marshal_BOOLEAN__FLAGSv	g_cclosure_marshal_BOOLEAN__FLAGSv

/* BOOLEAN:INT (../gtk/gtk/gtkmarshalers.list:35) */
extern
void _gtk_marshal_BOOLEAN__INT (GClosure     *closure,
                                GValue       *return_value,
                                guint         n_param_values,
                                const GValue *param_values,
                                gpointer      invocation_hint,
                                gpointer      marshal_data);
extern
void _gtk_marshal_BOOLEAN__INTv (GClosure *closure,
                                 GValue   *return_value,
                                 gpointer  instance,
                                 va_list   args,
                                 gpointer  marshal_data,
                                 int       n_params,
                                 GType    *param_types);

/* BOOLEAN:INT,INT (../gtk/gtk/gtkmarshalers.list:36) */
extern
void _gtk_marshal_BOOLEAN__INT_INT (GClosure     *closure,
                                    GValue       *return_value,
                                    guint         n_param_values,
                                    const GValue *param_values,
                                    gpointer      invocation_hint,
                                    gpointer      marshal_data);
extern
void _gtk_marshal_BOOLEAN__INT_INTv (GClosure *closure,
                                     GValue   *return_value,
                                     gpointer  instance,
                                     va_list   args,
                                     gpointer  marshal_data,
                                     int       n_params,
                                     GType    *param_types);

/* BOOLEAN:INT,INT,BOOLEAN,OBJECT (../gtk/gtk/gtkmarshalers.list:37) */
extern
void _gtk_marshal_BOOLEAN__INT_INT_BOOLEAN_OBJECT (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
                                                   const GValue *param_values,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);
extern
void _gtk_marshal_BOOLEAN__INT_INT_BOOLEAN_OBJECTv (GClosure *closure,
                                                    GValue   *return_value,
                                                    gpointer  instance,
                                                    va_list   args,
                                                    gpointer  marshal_data,
                                                    int       n_params,
                                                    GType    *param_types);

/* BOOLEAN:OBJECT,BOXED (../gtk/gtk/gtkmarshalers.list:38) */
extern
void _gtk_marshal_BOOLEAN__OBJECT_BOXED (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
                                         const GValue *param_values,
                                         gpointer      invocation_hint,
                                         gpointer      marshal_data);
extern
void _gtk_marshal_BOOLEAN__OBJECT_BOXEDv (GClosure *closure,
                                          GValue   *return_value,
                                          gpointer  instance,
                                          va_list   args,
                                          gpointer  marshal_data,
                                          int       n_params,
                                          GType    *param_types);

/* BOOLEAN:OBJECT,DOUBLE,DOUBLE (../gtk/gtk/gtkmarshalers.list:39) */
extern
void _gtk_marshal_BOOLEAN__OBJECT_DOUBLE_DOUBLE (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
                                                 const GValue *param_values,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);
extern
void _gtk_marshal_BOOLEAN__OBJECT_DOUBLE_DOUBLEv (GClosure *closure,
                                                  GValue   *return_value,
                                                  gpointer  instance,
                                                  va_list   args,
                                                  gpointer  marshal_data,
                                                  int       n_params,
                                                  GType    *param_types);

/* BOOLEAN:OBJECT,ENUM (../gtk/gtk/gtkmarshalers.list:40) */
extern
void _gtk_marshal_BOOLEAN__OBJECT_ENUM (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
                                        const GValue *param_values,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);
extern
void _gtk_marshal_BOOLEAN__OBJECT_ENUMv (GClosure *closure,
                                         GValue   *return_value,
                                         gpointer  instance,
                                         va_list   args,
                                         gpointer  marshal_data,
                                         int       n_params,
                                         GType    *param_types);

/* BOOLEAN:OBJECT,OBJECT,OBJECT (../gtk/gtk/gtkmarshalers.list:41) */
extern
void _gtk_marshal_BOOLEAN__OBJECT_OBJECT_OBJECT (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
                                                 const GValue *param_values,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);
extern
void _gtk_marshal_BOOLEAN__OBJECT_OBJECT_OBJECTv (GClosure *closure,
                                                  GValue   *return_value,
                                                  gpointer  instance,
                                                  va_list   args,
                                                  gpointer  marshal_data,
                                                  int       n_params,
                                                  GType    *param_types);

/* BOOLEAN:STRING (../gtk/gtk/gtkmarshalers.list:42) */
extern
void _gtk_marshal_BOOLEAN__STRING (GClosure     *closure,
                                   GValue       *return_value,
                                   guint         n_param_values,
                                   const GValue *param_values,
                                   gpointer      invocation_hint,
                                   gpointer      marshal_data);
extern
void _gtk_marshal_BOOLEAN__STRINGv (GClosure *closure,
                                    GValue   *return_value,
                                    gpointer  instance,
                                    va_list   args,
                                    gpointer  marshal_data,
                                    int       n_params,
                                    GType    *param_types);

/* BOOLEAN:UINT,UINT,FLAGS (../gtk/gtk/gtkmarshalers.list:43) */
extern
void _gtk_marshal_BOOLEAN__UINT_UINT_FLAGS (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);
extern
void _gtk_marshal_BOOLEAN__UINT_UINT_FLAGSv (GClosure *closure,
                                             GValue   *return_value,
                                             gpointer  instance,
                                             va_list   args,
                                             gpointer  marshal_data,
                                             int       n_params,
                                             GType    *param_types);

/* BOOLEAN:VOID (../gtk/gtk/gtkmarshalers.list:44) */
extern
void _gtk_marshal_BOOLEAN__VOID (GClosure     *closure,
                                 GValue       *return_value,
                                 guint         n_param_values,
                                 const GValue *param_values,
                                 gpointer      invocation_hint,
                                 gpointer      marshal_data);
extern
void _gtk_marshal_BOOLEAN__VOIDv (GClosure *closure,
                                  GValue   *return_value,
                                  gpointer  instance,
                                  va_list   args,
                                  gpointer  marshal_data,
                                  int       n_params,
                                  GType    *param_types);

/* FLAGS:OBJECT,DOUBLE,DOUBLE (../gtk/gtk/gtkmarshalers.list:45) */
extern
void _gtk_marshal_FLAGS__OBJECT_DOUBLE_DOUBLE (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
extern
void _gtk_marshal_FLAGS__OBJECT_DOUBLE_DOUBLEv (GClosure *closure,
                                                GValue   *return_value,
                                                gpointer  instance,
                                                va_list   args,
                                                gpointer  marshal_data,
                                                int       n_params,
                                                GType    *param_types);

/* FLAGS:DOUBLE,DOUBLE (../gtk/gtk/gtkmarshalers.list:46) */
extern
void _gtk_marshal_FLAGS__DOUBLE_DOUBLE (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
                                        const GValue *param_values,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);
extern
void _gtk_marshal_FLAGS__DOUBLE_DOUBLEv (GClosure *closure,
                                         GValue   *return_value,
                                         gpointer  instance,
                                         va_list   args,
                                         gpointer  marshal_data,
                                         int       n_params,
                                         GType    *param_types);

/* INT:INT (../gtk/gtk/gtkmarshalers.list:47) */
extern
void _gtk_marshal_INT__INT (GClosure     *closure,
                            GValue       *return_value,
                            guint         n_param_values,
                            const GValue *param_values,
                            gpointer      invocation_hint,
                            gpointer      marshal_data);
extern
void _gtk_marshal_INT__INTv (GClosure *closure,
                             GValue   *return_value,
                             gpointer  instance,
                             va_list   args,
                             gpointer  marshal_data,
                             int       n_params,
                             GType    *param_types);

/* INT:OBJECT,OBJECT,POINTER (../gtk/gtk/gtkmarshalers.list:48) */
extern
void _gtk_marshal_INT__OBJECT_OBJECT_POINTER (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
extern
void _gtk_marshal_INT__OBJECT_OBJECT_POINTERv (GClosure *closure,
                                               GValue   *return_value,
                                               gpointer  instance,
                                               va_list   args,
                                               gpointer  marshal_data,
                                               int       n_params,
                                               GType    *param_types);

/* INT:POINTER (../gtk/gtk/gtkmarshalers.list:49) */
extern
void _gtk_marshal_INT__POINTER (GClosure     *closure,
                                GValue       *return_value,
                                guint         n_param_values,
                                const GValue *param_values,
                                gpointer      invocation_hint,
                                gpointer      marshal_data);
extern
void _gtk_marshal_INT__POINTERv (GClosure *closure,
                                 GValue   *return_value,
                                 gpointer  instance,
                                 va_list   args,
                                 gpointer  marshal_data,
                                 int       n_params,
                                 GType    *param_types);

/* OBJECT:DOUBLE,DOUBLE (../gtk/gtk/gtkmarshalers.list:50) */
extern
void _gtk_marshal_OBJECT__DOUBLE_DOUBLE (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
                                         const GValue *param_values,
                                         gpointer      invocation_hint,
                                         gpointer      marshal_data);
extern
void _gtk_marshal_OBJECT__DOUBLE_DOUBLEv (GClosure *closure,
                                          GValue   *return_value,
                                          gpointer  instance,
                                          va_list   args,
                                          gpointer  marshal_data,
                                          int       n_params,
                                          GType    *param_types);

/* OBJECT:OBJECT (../gtk/gtk/gtkmarshalers.list:51) */
extern
void _gtk_marshal_OBJECT__OBJECT (GClosure     *closure,
                                  GValue       *return_value,
                                  guint         n_param_values,
                                  const GValue *param_values,
                                  gpointer      invocation_hint,
                                  gpointer      marshal_data);
extern
void _gtk_marshal_OBJECT__OBJECTv (GClosure *closure,
                                   GValue   *return_value,
                                   gpointer  instance,
                                   va_list   args,
                                   gpointer  marshal_data,
                                   int       n_params,
                                   GType    *param_types);

/* OBJECT:VOID (../gtk/gtk/gtkmarshalers.list:52) */
extern
void _gtk_marshal_OBJECT__VOID (GClosure     *closure,
                                GValue       *return_value,
                                guint         n_param_values,
                                const GValue *param_values,
                                gpointer      invocation_hint,
                                gpointer      marshal_data);
extern
void _gtk_marshal_OBJECT__VOIDv (GClosure *closure,
                                 GValue   *return_value,
                                 gpointer  instance,
                                 va_list   args,
                                 gpointer  marshal_data,
                                 int       n_params,
                                 GType    *param_types);

/* STRING:STRING (../gtk/gtk/gtkmarshalers.list:53) */
extern
void _gtk_marshal_STRING__STRING (GClosure     *closure,
                                  GValue       *return_value,
                                  guint         n_param_values,
                                  const GValue *param_values,
                                  gpointer      invocation_hint,
                                  gpointer      marshal_data);
extern
void _gtk_marshal_STRING__STRINGv (GClosure *closure,
                                   GValue   *return_value,
                                   gpointer  instance,
                                   va_list   args,
                                   gpointer  marshal_data,
                                   int       n_params,
                                   GType    *param_types);

/* VOID:BOXED,BOXED (../gtk/gtk/gtkmarshalers.list:54) */
extern
void _gtk_marshal_VOID__BOXED_BOXED (GClosure     *closure,
                                     GValue       *return_value,
                                     guint         n_param_values,
                                     const GValue *param_values,
                                     gpointer      invocation_hint,
                                     gpointer      marshal_data);
extern
void _gtk_marshal_VOID__BOXED_BOXEDv (GClosure *closure,
                                      GValue   *return_value,
                                      gpointer  instance,
                                      va_list   args,
                                      gpointer  marshal_data,
                                      int       n_params,
                                      GType    *param_types);

/* VOID:BOXED,BOXED,POINTER (../gtk/gtk/gtkmarshalers.list:55) */
extern
void _gtk_marshal_VOID__BOXED_BOXED_POINTER (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
extern
void _gtk_marshal_VOID__BOXED_BOXED_POINTERv (GClosure *closure,
                                              GValue   *return_value,
                                              gpointer  instance,
                                              va_list   args,
                                              gpointer  marshal_data,
                                              int       n_params,
                                              GType    *param_types);

/* VOID:BOXED,ENUM (../gtk/gtk/gtkmarshalers.list:56) */
extern
void _gtk_marshal_VOID__BOXED_ENUM (GClosure     *closure,
                                    GValue       *return_value,
                                    guint         n_param_values,
                                    const GValue *param_values,
                                    gpointer      invocation_hint,
                                    gpointer      marshal_data);
extern
void _gtk_marshal_VOID__BOXED_ENUMv (GClosure *closure,
                                     GValue   *return_value,
                                     gpointer  instance,
                                     va_list   args,
                                     gpointer  marshal_data,
                                     int       n_params,
                                     GType    *param_types);

/* VOID:BOXED,OBJECT (../gtk/gtk/gtkmarshalers.list:57) */
extern
void _gtk_marshal_VOID__BOXED_OBJECT (GClosure     *closure,
                                      GValue       *return_value,
                                      guint         n_param_values,
                                      const GValue *param_values,
                                      gpointer      invocation_hint,
                                      gpointer      marshal_data);
extern
void _gtk_marshal_VOID__BOXED_OBJECTv (GClosure *closure,
                                       GValue   *return_value,
                                       gpointer  instance,
                                       va_list   args,
                                       gpointer  marshal_data,
                                       int       n_params,
                                       GType    *param_types);

/* VOID:BOXED,STRING,INT (../gtk/gtk/gtkmarshalers.list:58) */
extern
void _gtk_marshal_VOID__BOXED_STRING_INT (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
                                          const GValue *param_values,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);
extern
void _gtk_marshal_VOID__BOXED_STRING_INTv (GClosure *closure,
                                           GValue   *return_value,
                                           gpointer  instance,
                                           va_list   args,
                                           gpointer  marshal_data,
                                           int       n_params,
                                           GType    *param_types);

/* VOID:DOUBLE,DOUBLE (../gtk/gtk/gtkmarshalers.list:59) */
extern
void _gtk_marshal_VOID__DOUBLE_DOUBLE (GClosure     *closure,
                                       GValue       *return_value,
                                       guint         n_param_values,
                                       const GValue *param_values,
                                       gpointer      invocation_hint,
                                       gpointer      marshal_data);
extern
void _gtk_marshal_VOID__DOUBLE_DOUBLEv (GClosure *closure,
                                        GValue   *return_value,
                                        gpointer  instance,
                                        va_list   args,
                                        gpointer  marshal_data,
                                        int       n_params,
                                        GType    *param_types);

/* VOID:DOUBLE,DOUBLE,UINT,BOXED (../gtk/gtk/gtkmarshalers.list:60) */
extern
void _gtk_marshal_VOID__DOUBLE_DOUBLE_UINT_BOXED (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
                                                  const GValue *param_values,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);
extern
void _gtk_marshal_VOID__DOUBLE_DOUBLE_UINT_BOXEDv (GClosure *closure,
                                                   GValue   *return_value,
                                                   gpointer  instance,
                                                   va_list   args,
                                                   gpointer  marshal_data,
                                                   int       n_params,
                                                   GType    *param_types);

/* VOID:ENUM,DOUBLE (../gtk/gtk/gtkmarshalers.list:61) */
extern
void _gtk_marshal_VOID__ENUM_DOUBLE (GClosure     *closure,
                                     GValue       *return_value,
                                     guint         n_param_values,
                                     const GValue *param_values,
                                     gpointer      invocation_hint,
                                     gpointer      marshal_data);
extern
void _gtk_marshal_VOID__ENUM_DOUBLEv (GClosure *closure,
                                      GValue   *return_value,
                                      gpointer  instance,
                                      va_list   args,
                                      gpointer  marshal_data,
                                      int       n_params,
                                      GType    *param_types);

/* VOID:ENUM,INT (../gtk/gtk/gtkmarshalers.list:62) */
extern
void _gtk_marshal_VOID__ENUM_INT (GClosure     *closure,
                                  GValue       *return_value,
                                  guint         n_param_values,
                                  const GValue *param_values,
                                  gpointer      invocation_hint,
                                  gpointer      marshal_data);
extern
void _gtk_marshal_VOID__ENUM_INTv (GClosure *closure,
                                   GValue   *return_value,
                                   gpointer  instance,
                                   va_list   args,
                                   gpointer  marshal_data,
                                   int       n_params,
                                   GType    *param_types);

/* VOID:ENUM,INT,BOOLEAN (../gtk/gtk/gtkmarshalers.list:63) */
extern
void _gtk_marshal_VOID__ENUM_INT_BOOLEAN (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
                                          const GValue *param_values,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);
extern
void _gtk_marshal_VOID__ENUM_INT_BOOLEANv (GClosure *closure,
                                           GValue   *return_value,
                                           gpointer  instance,
                                           va_list   args,
                                           gpointer  marshal_data,
                                           int       n_params,
                                           GType    *param_types);

/* VOID:ENUM,INT,BOOLEAN,BOOLEAN (../gtk/gtk/gtkmarshalers.list:64) */
extern
void _gtk_marshal_VOID__ENUM_INT_BOOLEAN_BOOLEAN (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
                                                  const GValue *param_values,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);
extern
void _gtk_marshal_VOID__ENUM_INT_BOOLEAN_BOOLEANv (GClosure *closure,
                                                   GValue   *return_value,
                                                   gpointer  instance,
                                                   va_list   args,
                                                   gpointer  marshal_data,
                                                   int       n_params,
                                                   GType    *param_types);

/* VOID:INT,DOUBLE,DOUBLE (../gtk/gtk/gtkmarshalers.list:65) */
extern
void _gtk_marshal_VOID__INT_DOUBLE_DOUBLE (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
                                           const GValue *param_values,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);
extern
void _gtk_marshal_VOID__INT_DOUBLE_DOUBLEv (GClosure *closure,
                                            GValue   *return_value,
                                            gpointer  instance,
                                            va_list   args,
                                            gpointer  marshal_data,
                                            int       n_params,
                                            GType    *param_types);

/* VOID:INT,INT,INT (../gtk/gtk/gtkmarshalers.list:66) */
extern
void _gtk_marshal_VOID__INT_INT_INT (GClosure     *closure,
                                     GValue       *return_value,
                                     guint         n_param_values,
                                     const GValue *param_values,
                                     gpointer      invocation_hint,
                                     gpointer      marshal_data);
extern
void _gtk_marshal_VOID__INT_INT_INTv (GClosure *closure,
                                      GValue   *return_value,
                                      gpointer  instance,
                                      va_list   args,
                                      gpointer  marshal_data,
                                      int       n_params,
                                      GType    *param_types);

/* VOID:OBJECT,BOOLEAN (../gtk/gtk/gtkmarshalers.list:67) */
extern
void _gtk_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
                                        const GValue *param_values,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);
extern
void _gtk_marshal_VOID__OBJECT_BOOLEANv (GClosure *closure,
                                         GValue   *return_value,
                                         gpointer  instance,
                                         va_list   args,
                                         gpointer  marshal_data,
                                         int       n_params,
                                         GType    *param_types);

/* VOID:OBJECT,BOXED,BOOLEAN,BOOLEAN (../gtk/gtk/gtkmarshalers.list:68) */
extern
void _gtk_marshal_VOID__OBJECT_BOXED_BOOLEAN_BOOLEAN (GClosure     *closure,
                                                      GValue       *return_value,
                                                      guint         n_param_values,
                                                      const GValue *param_values,
                                                      gpointer      invocation_hint,
                                                      gpointer      marshal_data);
extern
void _gtk_marshal_VOID__OBJECT_BOXED_BOOLEAN_BOOLEANv (GClosure *closure,
                                                       GValue   *return_value,
                                                       gpointer  instance,
                                                       va_list   args,
                                                       gpointer  marshal_data,
                                                       int       n_params,
                                                       GType    *param_types);

/* VOID:OBJECT,BOXED,BOXED (../gtk/gtk/gtkmarshalers.list:69) */
extern
void _gtk_marshal_VOID__OBJECT_BOXED_BOXED (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);
extern
void _gtk_marshal_VOID__OBJECT_BOXED_BOXEDv (GClosure *closure,
                                             GValue   *return_value,
                                             gpointer  instance,
                                             va_list   args,
                                             gpointer  marshal_data,
                                             int       n_params,
                                             GType    *param_types);

/* VOID:OBJECT,FLAGS (../gtk/gtk/gtkmarshalers.list:70) */
extern
void _gtk_marshal_VOID__OBJECT_FLAGS (GClosure     *closure,
                                      GValue       *return_value,
                                      guint         n_param_values,
                                      const GValue *param_values,
                                      gpointer      invocation_hint,
                                      gpointer      marshal_data);
extern
void _gtk_marshal_VOID__OBJECT_FLAGSv (GClosure *closure,
                                       GValue   *return_value,
                                       gpointer  instance,
                                       va_list   args,
                                       gpointer  marshal_data,
                                       int       n_params,
                                       GType    *param_types);

/* VOID:OBJECT,INT (../gtk/gtk/gtkmarshalers.list:71) */
extern
void _gtk_marshal_VOID__OBJECT_INT (GClosure     *closure,
                                    GValue       *return_value,
                                    guint         n_param_values,
                                    const GValue *param_values,
                                    gpointer      invocation_hint,
                                    gpointer      marshal_data);
extern
void _gtk_marshal_VOID__OBJECT_INTv (GClosure *closure,
                                     GValue   *return_value,
                                     gpointer  instance,
                                     va_list   args,
                                     gpointer  marshal_data,
                                     int       n_params,
                                     GType    *param_types);

/* VOID:OBJECT,INT,INT (../gtk/gtk/gtkmarshalers.list:72) */
extern
void _gtk_marshal_VOID__OBJECT_INT_INT (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
                                        const GValue *param_values,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);
extern
void _gtk_marshal_VOID__OBJECT_INT_INTv (GClosure *closure,
                                         GValue   *return_value,
                                         gpointer  instance,
                                         va_list   args,
                                         gpointer  marshal_data,
                                         int       n_params,
                                         GType    *param_types);

/* VOID:OBJECT,INT,OBJECT (../gtk/gtk/gtkmarshalers.list:73) */
extern
void _gtk_marshal_VOID__OBJECT_INT_OBJECT (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
                                           const GValue *param_values,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);
extern
void _gtk_marshal_VOID__OBJECT_INT_OBJECTv (GClosure *closure,
                                            GValue   *return_value,
                                            gpointer  instance,
                                            va_list   args,
                                            gpointer  marshal_data,
                                            int       n_params,
                                            GType    *param_types);

/* VOID:OBJECT,OBJECT (../gtk/gtk/gtkmarshalers.list:74) */
extern
void _gtk_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                       GValue       *return_value,
                                       guint         n_param_values,
                                       const GValue *param_values,
                                       gpointer      invocation_hint,
                                       gpointer      marshal_data);
extern
void _gtk_marshal_VOID__OBJECT_OBJECTv (GClosure *closure,
                                        GValue   *return_value,
                                        gpointer  instance,
                                        va_list   args,
                                        gpointer  marshal_data,
                                        int       n_params,
                                        GType    *param_types);

/* VOID:OBJECT,OBJECT,BOOLEAN (../gtk/gtk/gtkmarshalers.list:75) */
extern
void _gtk_marshal_VOID__OBJECT_OBJECT_BOOLEAN (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
extern
void _gtk_marshal_VOID__OBJECT_OBJECT_BOOLEANv (GClosure *closure,
                                                GValue   *return_value,
                                                gpointer  instance,
                                                va_list   args,
                                                gpointer  marshal_data,
                                                int       n_params,
                                                GType    *param_types);

/* VOID:OBJECT,OBJECT,BOXED,STRING (../gtk/gtk/gtkmarshalers.list:76) */
extern
void _gtk_marshal_VOID__OBJECT_OBJECT_BOXED_STRING (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
                                                    const GValue *param_values,
                                                    gpointer      invocation_hint,
                                                    gpointer      marshal_data);
extern
void _gtk_marshal_VOID__OBJECT_OBJECT_BOXED_STRINGv (GClosure *closure,
                                                     GValue   *return_value,
                                                     gpointer  instance,
                                                     va_list   args,
                                                     gpointer  marshal_data,
                                                     int       n_params,
                                                     GType    *param_types);

/* VOID:OBJECT,OBJECT,OBJECT (../gtk/gtk/gtkmarshalers.list:77) */
extern
void _gtk_marshal_VOID__OBJECT_OBJECT_OBJECT (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
extern
void _gtk_marshal_VOID__OBJECT_OBJECT_OBJECTv (GClosure *closure,
                                               GValue   *return_value,
                                               gpointer  instance,
                                               va_list   args,
                                               gpointer  marshal_data,
                                               int       n_params,
                                               GType    *param_types);

/* VOID:OBJECT,POINTER,INT (../gtk/gtk/gtkmarshalers.list:78) */
extern
void _gtk_marshal_VOID__OBJECT_POINTER_INT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);
extern
void _gtk_marshal_VOID__OBJECT_POINTER_INTv (GClosure *closure,
                                             GValue   *return_value,
                                             gpointer  instance,
                                             va_list   args,
                                             gpointer  marshal_data,
                                             int       n_params,
                                             GType    *param_types);

/* VOID:OBJECT,STRING (../gtk/gtk/gtkmarshalers.list:79) */
extern
void _gtk_marshal_VOID__OBJECT_STRING (GClosure     *closure,
                                       GValue       *return_value,
                                       guint         n_param_values,
                                       const GValue *param_values,
                                       gpointer      invocation_hint,
                                       gpointer      marshal_data);
extern
void _gtk_marshal_VOID__OBJECT_STRINGv (GClosure *closure,
                                        GValue   *return_value,
                                        gpointer  instance,
                                        va_list   args,
                                        gpointer  marshal_data,
                                        int       n_params,
                                        GType    *param_types);

/* VOID:OBJECT,UINT (../gtk/gtk/gtkmarshalers.list:80) */
extern
void _gtk_marshal_VOID__OBJECT_UINT (GClosure     *closure,
                                     GValue       *return_value,
                                     guint         n_param_values,
                                     const GValue *param_values,
                                     gpointer      invocation_hint,
                                     gpointer      marshal_data);
extern
void _gtk_marshal_VOID__OBJECT_UINTv (GClosure *closure,
                                      GValue   *return_value,
                                      gpointer  instance,
                                      va_list   args,
                                      gpointer  marshal_data,
                                      int       n_params,
                                      GType    *param_types);

/* VOID:STRING,BOXED (../gtk/gtk/gtkmarshalers.list:81) */
extern
void _gtk_marshal_VOID__STRING_BOXED (GClosure     *closure,
                                      GValue       *return_value,
                                      guint         n_param_values,
                                      const GValue *param_values,
                                      gpointer      invocation_hint,
                                      gpointer      marshal_data);
extern
void _gtk_marshal_VOID__STRING_BOXEDv (GClosure *closure,
                                       GValue   *return_value,
                                       gpointer  instance,
                                       va_list   args,
                                       gpointer  marshal_data,
                                       int       n_params,
                                       GType    *param_types);

/* VOID:STRING,INT,POINTER (../gtk/gtk/gtkmarshalers.list:82) */
extern
void _gtk_marshal_VOID__STRING_INT_POINTER (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);
extern
void _gtk_marshal_VOID__STRING_INT_POINTERv (GClosure *closure,
                                             GValue   *return_value,
                                             gpointer  instance,
                                             va_list   args,
                                             gpointer  marshal_data,
                                             int       n_params,
                                             GType    *param_types);

/* VOID:STRING,STRING (../gtk/gtk/gtkmarshalers.list:83) */
extern
void _gtk_marshal_VOID__STRING_STRING (GClosure     *closure,
                                       GValue       *return_value,
                                       guint         n_param_values,
                                       const GValue *param_values,
                                       gpointer      invocation_hint,
                                       gpointer      marshal_data);
extern
void _gtk_marshal_VOID__STRING_STRINGv (GClosure *closure,
                                        GValue   *return_value,
                                        gpointer  instance,
                                        va_list   args,
                                        gpointer  marshal_data,
                                        int       n_params,
                                        GType    *param_types);

/* VOID:STRING,UINT,FLAGS,UINT (../gtk/gtk/gtkmarshalers.list:84) */
extern
void _gtk_marshal_VOID__STRING_UINT_FLAGS_UINT (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
                                                const GValue *param_values,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);
extern
void _gtk_marshal_VOID__STRING_UINT_FLAGS_UINTv (GClosure *closure,
                                                 GValue   *return_value,
                                                 gpointer  instance,
                                                 va_list   args,
                                                 gpointer  marshal_data,
                                                 int       n_params,
                                                 GType    *param_types);

/* VOID:UINT,STRING (../gtk/gtk/gtkmarshalers.list:85) */
extern
void _gtk_marshal_VOID__UINT_STRING (GClosure     *closure,
                                     GValue       *return_value,
                                     guint         n_param_values,
                                     const GValue *param_values,
                                     gpointer      invocation_hint,
                                     gpointer      marshal_data);
extern
void _gtk_marshal_VOID__UINT_STRINGv (GClosure *closure,
                                      GValue   *return_value,
                                      gpointer  instance,
                                      va_list   args,
                                      gpointer  marshal_data,
                                      int       n_params,
                                      GType    *param_types);

/* VOID:UINT,STRING,UINT (../gtk/gtk/gtkmarshalers.list:86) */
extern
void _gtk_marshal_VOID__UINT_STRING_UINT (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
                                          const GValue *param_values,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);
extern
void _gtk_marshal_VOID__UINT_STRING_UINTv (GClosure *closure,
                                           GValue   *return_value,
                                           gpointer  instance,
                                           va_list   args,
                                           gpointer  marshal_data,
                                           int       n_params,
                                           GType    *param_types);

/* VOID:UINT,UINT (../gtk/gtk/gtkmarshalers.list:87) */
extern
void _gtk_marshal_VOID__UINT_UINT (GClosure     *closure,
                                   GValue       *return_value,
                                   guint         n_param_values,
                                   const GValue *param_values,
                                   gpointer      invocation_hint,
                                   gpointer      marshal_data);
extern
void _gtk_marshal_VOID__UINT_UINTv (GClosure *closure,
                                    GValue   *return_value,
                                    gpointer  instance,
                                    va_list   args,
                                    gpointer  marshal_data,
                                    int       n_params,
                                    GType    *param_types);

/* VOID:UINT,UINT,FLAGS (../gtk/gtk/gtkmarshalers.list:88) */
extern
void _gtk_marshal_VOID__UINT_UINT_FLAGS (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
                                         const GValue *param_values,
                                         gpointer      invocation_hint,
                                         gpointer      marshal_data);
extern
void _gtk_marshal_VOID__UINT_UINT_FLAGSv (GClosure *closure,
                                          GValue   *return_value,
                                          gpointer  instance,
                                          va_list   args,
                                          gpointer  marshal_data,
                                          int       n_params,
                                          GType    *param_types);


G_END_DECLS
